%global domain          github.com
%global org             kata-containers
%global repo            shim
%global download        %{domain}/%{org}/%{repo}
%global importname      %{download}

# Find debug informations from a go build (will be better in F31)
%global gobuild go build -ldflags=-linkmode=external

Name:      kata-%{repo}
Version:   1.8.0
Release:   1%{?dist}
Url:       https://%{download}
Source0:   https://%{download}/archive/%{version}/%{name}-%{version}.tar.gz
Summary:   A shim running in the host for teh Kata Containers project
Group:     Development/Tools
License:   ASL 2.0

# F31: Add BuildRequires: go-rpm-macros
BuildRequires: %{?suse_version:go1.12} %{!?suse_version:golang}

Provides: bundled(golang(github.com/Azure/go-ansiterm)) = d6e3b3328b783f23731bc4d058875b0371ff8109
Provides: bundled(golang(github.com/davecgh/go-spew)) = v1.1.0
Provides: bundled(golang(github.com/docker/docker)) = bc183a0062c1283cfc47f42ec78501868629dd2b
Provides: bundled(golang(github.com/gogo/protobuf)) = 342cbe0a04158f6dcb03ca0079991a51a4248c02
Provides: bundled(golang(github.com/golang/protobuf)) = 1e59b77b52bf8e4b449a57e6f79f21226d571845
Provides: bundled(golang(github.com/kata-containers/agent)) = 8f22514ae5790f3b6953cf93692e663fa29469e3
Provides: bundled(golang(github.com/kr/pty)) = v1.1.0
Provides: bundled(golang(github.com/mdlayher/vsock)) = 738c88d6e4cfd60e8124a5344fa10d205fd828b9
Provides: bundled(golang(github.com/moby/moby)) = v1.13.1
Provides: bundled(golang(github.com/opencontainers/runtime-spec)) = 4e3b9264a330d094b0386c3703c5f379119711e8
Provides: bundled(golang(github.com/pmezard/go-difflib)) = v1.0.0
Provides: bundled(golang(github.com/sirupsen/logrus)) = v1.0.4
Provides: bundled(golang(github.com/stretchr/testify)) = v1.2.0
Provides: bundled(golang(golang.org/x/crypto)) = 13931e22f9e72ea58bb73048bc752b48c6d4d4ac
Provides: bundled(golang(golang.org/x/net)) = a8b9294777976932365dabb6640cf1468d95c70f
Provides: bundled(golang(golang.org/x/sys)) = 810d7000345868fc619eb81f46307107118f4ae1
Provides: bundled(golang(golang.org/x/text)) = e19ae1496984b1c655b8044a65c0300a3c878dd3
Provides: bundled(golang(google.golang.org/genproto)) = a8101f21cf983e773d0c1133ebc5424792003214
Provides: bundled(golang(google.golang.org/grpc)) = v1.8.0

%description
This project implements a shim called kata-shim for the Kata Containers project.

Kata Containers is an open source project and community working to
build a standard implementation of lightweight Virtual Machines (VMs)
that feel and perform like containers, but provide the workload
isolation and security advantages of VMs.

The shim runs in the host environment, handling standard I/O and
signals on behalf of the container process which runs inside the
virtual machine.

%prep
%autosetup -n %{repo}-%{version}

%build
# Adjust for go build requirements
# Future: Use %gopkginstall
# export GOROOT="$(pwd)/go"
export GOPATH="$(pwd)/go"

mkdir go
mv vendor go/src
mkdir -p go/src/%{domain}/%{org}
ln -s $(pwd)/../%{repo}-%{version} go/src/%{importname}
cd go/src/%{importname}

%gobuild -ldflags "-X main.version=%{version}" -o bin/%{name} %{importname} 

%install
install -D bin/%{name} %{buildroot}%{_libexecdir}/kata-containers/%{name}

%check
export http_proxy=http://127.0.0.1:9/
export https_proxy=http://127.0.0.1:9/
export no_proxy=localhost

%files
%license LICENSE
%doc CODE_OF_CONDUCT.md CONTRIBUTING.md README.md 
%dir %{_libexecdir}/kata-containers
%{_libexecdir}/kata-containers/%{name}

%changelog
* Tue Jul 30 2019 Christophe de Dinechin <dinechin@redhat.com> - 1.8.0-1
- Update to 1.8.0 release

* Fri Jul 12 2019 Christophe de Dinechin <dinechin@redhat.com> - 1.7.3-1
- Update to 1.7.3 release, cleanup spec file

* Wed Nov 21 2018 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.3.1-6.git58f757d
- use macros where possible

* Wed Nov 21 2018 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.3.1-5.git58f757d
- build with %%gobuild

* Wed Nov 21 2018 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.3.1-4.git58f757d
- build for all supported arches

* Wed Nov 21 2018 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.3.1-3.git58f757d
- no need for make as BR

* Mon Nov 12 2018 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.3.1-2.git58f757d
- bundled Provides

* Sat Nov 10 2018 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.3.1-1.git58f757d
- bump to v1.3.1
- built commit 58f757d

* Thu Jun 14 2018 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.0.0-1.git087a537
- first build (ready for Fedora review)
